==> openejb-jee-4.0.0-sources.jar: org/apache/openejb/jee/jba/SecurityIdentity.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.jee.jba;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "runAsPrincipal"
})
@XmlRootElement(name = "security-identity")
public class SecurityIdentity {

    @XmlElement(name = "run-as-principal", required = true)
    protected String runAsPrincipal;

    /**
     * Gets the value of the runAsPrincipal property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRunAsPrincipal() {
        return runAsPrincipal;
    }

    /**
     * Sets the value of the runAsPrincipal property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRunAsPrincipal(String value) {
        this.runAsPrincipal = value;
    }

}

==> openejb-jee-8.0.3-sources.jar: org/apache/openejb/jee/jba/SecurityIdentity.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.jee.jba;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "runAsPrincipal"
})
@XmlRootElement(name = "security-identity")
public class SecurityIdentity {

    @XmlElement(name = "run-as-principal", required = true)
    protected String runAsPrincipal;

    /**
     * Gets the value of the runAsPrincipal property.
     *
     * @return possible object is
     * {@link String }
     */
    public String getRunAsPrincipal() {
        return runAsPrincipal;
    }

    /**
     * Sets the value of the runAsPrincipal property.
     *
     * @param value allowed object is
     *              {@link String }
     */
    public void setRunAsPrincipal(final String value) {
        this.runAsPrincipal = value;
    }

}
